# pyLearnAlgorithms
this package was developed as one of the results of a research project developed at the Federal University of Campina Grande.

## Getting Started
#### Dependencies
You need Python 3.6 or later to use **pyLearnAlgorithms**. You can find it at [python.org](https://www.python.org/).

You also need numpy, scipy, pandas and matplotlib packages. If you have pip, just run:
```
pip install numpy
pip install scipy
pip install pandas]
ip install matplotlib
```
#### Installation
Clone this repo to your local machine using:
```
git clone https://github.com/Alyssonmach/pyLearnAlgorithms.git
```

## Features
- Solving linear regression problems
- Solving polynomial regression problems
- Open data of different formats
- Split the data into different strata to analyze the model
- File structure for PyPI packages
- Setup with package informations
- License example
